@@ -2,7 +2,7 @@ from src.api import FishPi
 import json
 import time
 import enum
-from src.utils import utils
+from src.utils.utils import RPS_LOSED, RPS_ZERO, RPS_SUCCESS
 from .config import GLOBAL_CONFIG
 
 CODE = enum.Enum('REDPACKET_CODE', ['SUCCESS', 'LOSED', 'NOT_ME', "ZERO"])
@@ -10,18 +10,19 @@ CODE = enum.Enum('REDPACKET_CODE', ['SUCCESS', 'LOSED', 'NOT_ME', "ZERO"])
 
 def __open_redpacket_render(username, redpacket: dict) -> CODE:
     who = redpacket['who']
+    sender = redpacket['info']['userName']
     for i in who:
         if i['userName'] == username:
             if i['userMoney'] < 0:
-                print("红包助手: 悲剧，你竟然被反向抢了红包(" + str(i['userMoney']) + ")!")
+                print(f"红包助手: 悲剧，你竟然被{sender}反向抢了红包({str(i['userMoney'])})积分!")
                 return CODE.LOSED
             elif i['userMoney'] == 0:
-                print("红包助手: 零溢事件，抢到了一个空的红包(" + str(i['userMoney']) + ")!")
+                print(f"红包助手: 零溢事件，{sender}的红包抢到了({str(i['userMoney'])})积分!")
                 return CODE.ZERO
             else:
-                print("红包助手: 恭喜，你抢到了一个红包(" + str(i['userMoney']) + ")!")
+                print(f"红包助手: 恭喜，你抢到了{sender}的红包({str(i['userMoney'])})积分!")
                 return CODE.SUCCESS
-    print("红包助手: 遗憾，比别人慢了一点点，建议换宽带!")
+    print(f"红包助手: 遗憾 {sender}的红包没有抢到，比别人慢了一点点，建议换宽带!")
     return CODE.NOT_ME
 
 
@@ -40,11 +41,11 @@ def open_rock_paper_scissors_packet(api: FishPi, red_packet_id) -> None:
         return
     code = __open_redpacket_render(api.current_user, resp_json)
     if code == CODE.SUCCESS:
-        api.chatroom.send(utils.RPS_SUCCESS)
+        api.chatroom.send(RPS_SUCCESS)
     elif code == CODE.LOSED:
-        api.chatroom.send(utils.RPS_LOSED)
+        api.chatroom.send(RPS_LOSED)
     elif code == CODE.ZERO:
-        api.chatroom.send(utils.RPS_ZERO)    
+        api.chatroom.send(RPS_ZERO)
 
 
 def rush_redpacket(api: FishPi, redpacket):
@@ -54,19 +55,19 @@ def rush_redpacket(api: FishPi, redpacket):
         print('\t\t\t\t\t\t发送了一个红包')
         return
     if (GLOBAL_CONFIG.redpacket_config.red_packet_switch == False):
-        print('红包助手: '+sender+'发送了一个红包 你错过了这个红包，请开启抢红包模式！')
+        print(f'红包助手: {sender}发送了一个红包 你错过了这个红包，请开启抢红包模式！')
         return
     sender = redpacket['userName']
     content = json.loads(redpacket['content'])
     if content['type'] == 'heartbeat':
         if GLOBAL_CONFIG.redpacket_config.heartbeat:
             if GLOBAL_CONFIG.redpacket_config.smart_mode:
-                print('红包助手: ' + sender + ' 发了一个心跳红包')
+                print(f'红包助手: {sender}发了一个心跳红包')
                 __analyzeHeartbeatRedPacket(api, redpacket['oId'])
                 return
             open_red_packet(api, redpacket['oId'])
         else:
-            print('红包助手: '+sender+' 发送了一个心跳红包, 你选择跳过了这个心跳红包！不尝试赌一下人品吗？')
+            print(f'红包助手: {sender}发送了一个心跳红包, 你选择跳过了这个心跳红包！不尝试赌一下人品吗？')
             return
     if content['type'] == 'rockPaperScissors':
         print(
@@ -79,7 +80,7 @@ def rush_redpacket(api: FishPi, redpacket):
         else:
             open_rock_paper_scissors_packet(api, redpacket['oId'])
     else:
-        print('红包助手: ' + sender+' 发送了一个红包, 但社区规定，助手抢红包要等' +
+        print(f'红包助手: {sender} 发送了一个红包, 但社区规定，助手抢红包要等' +
               str(GLOBAL_CONFIG.redpacket_config.rate)+'秒哦～')
         time.sleep(GLOBAL_CONFIG.redpacket_config.rate)
         open_red_packet(api, redpacket['oId'])
@@ -100,7 +101,7 @@ def __analyze(api: FishPi, packet, red_packet_id, ctime, sender):
     count = packet['count']
     got = packet['got']
     if packet['count'] == packet['got']:
-        print('红包助手: '+sender+' 发送的心跳红包, 遗憾没有抢到，比别人慢了一点点，建议换宽带!')
+        print(f'红包助手: {sender} 发送的心跳红包, 遗憾没有抢到，比别人慢了一点点，建议换宽带!')
         return
 
     probability = 1 / (count - got)
@@ -108,7 +109,7 @@ def __analyze(api: FishPi, packet, red_packet_id, ctime, sender):
         if get['userMoney'] > 0:
             print('红包助手: '+sender+' 发送的心跳红包已无效，智能跳坑！')
             return
-    print('红包助手: 此心跳红包的中奖概率为:'+str(probability))
+    print(f'红包助手: 此心跳红包的中奖概率为:{str(probability)}')
     if probability >= GLOBAL_CONFIG.redpacket_config.threshold:
         open_red_packet(api, red_packet_id)
     else:
